==> Dist-Zilla-Plugin-DistManifestTests-1.100710.tar.gz: Dist-Zilla-Plugin-DistManifestTests-1.100710/lib/Dist/Zilla/Plugin/DistManifestTests.pm <==
use 5.008;
use strict;
use warnings;

package Dist::Zilla::Plugin::DistManifestTests;
our $VERSION = '1.100710';
# ABSTRACT: release tests for the manifest
use Moose;
use Test::DistManifest;
extends 'Dist::Zilla::Plugin::InlineFiles';

__PACKAGE__->meta->make_immutable;
no Moose;
1;




=pod

=head1 NAME

Dist::Zilla::Plugin::DistManifestTests - release tests for the manifest

=head1 VERSION

version 1.100710

=head1 SYNOPSIS

In C<dist.ini>:

    [DistManifestTests]

=head1 DESCRIPTION

This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing the
following files

  xt/release/dist-manifest.t - a standard Test::DistManifest test

=for test_synopsis 1;
__END__

=head1 INSTALLATION

See perlmodinstall for information and options on installing Perl modules.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests through the web interface at
L<http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-DistManifestTests>.

=head1 AVAILABILITY

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see
L<http://search.cpan.org/dist/Dist-Zilla-Plugin-DistManifestTests/>.

The development version lives at
L<http://github.com/hanekomu/Dist-Zilla-Plugin-DistManifestTests/>.
Instead of sending patches, please fork this project using the standard git
and github infrastructure.

=head1 AUTHOR

  Marcel Gruenauer <marcel@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2010 by Marcel Gruenauer.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__DATA__
___[ xt/release/dist-manifest.t ]___
#!perl

use Test::More;

eval "use Test::DistManifest";
plan skip_all => "Test::DistManifest required for testing the manifest"
  if $@;
manifest_ok();

==> Dist-Zilla-Plugin-DistManifestTests-1.101420.tar.gz: Dist-Zilla-Plugin-DistManifestTests-1.101420/lib/Dist/Zilla/Plugin/DistManifestTests.pm <==
use 5.008;
use strict;
use warnings;

package Dist::Zilla::Plugin::DistManifestTests;
BEGIN {
  $Dist::Zilla::Plugin::DistManifestTests::VERSION = '1.101420';
}
# ABSTRACT: Release tests for the manifest
use Moose;
extends 'Dist::Zilla::Plugin::InlineFiles';

__PACKAGE__->meta->make_immutable;
no Moose;
1;




=pod

=head1 NAME

Dist::Zilla::Plugin::DistManifestTests - Release tests for the manifest

=head1 VERSION

version 1.101420

=head1 SYNOPSIS

In C<dist.ini>:

    [DistManifestTests]

=head1 DESCRIPTION

This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing the
following file:

  xt/release/dist-manifest.t - a standard Test::DistManifest test

=for test_synopsis 1;
__END__

=head1 INSTALLATION

See perlmodinstall for information and options on installing Perl modules.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests through the web interface at
L<http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-DistManifestTests>.

=head1 AVAILABILITY

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see
L<http://search.cpan.org/dist/Dist-Zilla-Plugin-DistManifestTests/>.

The development version lives at
L<http://github.com/hanekomu/Dist-Zilla-Plugin-DistManifestTests/>.
Instead of sending patches, please fork this project using the standard git
and github infrastructure.

=head1 AUTHOR

  Marcel Gruenauer <marcel@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2010 by Marcel Gruenauer.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__DATA__
___[ xt/release/dist-manifest.t ]___
#!perl

use Test::More;

eval "use Test::DistManifest";
plan skip_all => "Test::DistManifest required for testing the manifest"
  if $@;
manifest_ok();
